package
Version:
v0.1.5
Opens a new window with list of versions in this module.
Published: Apr 25, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Message struct {
Id int64 `json:"id"`
Tag string `json:"tag"`
Body string `json:"body"`
Time int64 `json:"time"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.